@@ -8,19 +8,14 @@ package W3C::SOAP::Header::Security::Username;
 
 use Moose;
 use warnings;
-use version;
 use Carp;
-use Scalar::Util;
-use List::Util;
-#use List::MoreUtils;
-use Data::Dumper qw/Dumper/;
 use DateTime;
 use Time::HiRes qw/gettimeofday/;
 use English qw/ -no_match_vars /;
 
 extends 'W3C::SOAP::Header::Security';
 
-our $VERSION     = version->new('0.11');
+our $VERSION = 0.12;
 my $id = 0;
 
 has username => (
@@ -85,7 +80,7 @@ W3C::SOAP::Header::Security::Username - Creates a WS-Security User name object
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Header::Security::Username version 0.11.
+This documentation refers to W3C::SOAP::Header::Security::Username version 0.12.
 
 =head1 SYNOPSIS
 
