@@ -8,7 +8,6 @@ package W3C::SOAP::Utils;
 
 use strict;
 use warnings;
-use version;
 use Carp;
 use Scalar::Util;
 use List::Util;
@@ -23,7 +22,7 @@ Moose::Exporter->setup_import_methods(
     with_meta => ['operation'],
 );
 
-our $VERSION     = version->new('0.11');
+our $VERSION = 0.12;
 
 sub split_ns {
     my ($tag) = @_;
@@ -50,7 +49,7 @@ sub ns2module {
     my $uri = URI->new($ns);
 
     # URI's which have a host an a path are converted Java style name spacing
-    if ( $uri->can('host') && $uri->can('path') ) {
+    if ( $uri->can('host') ) {
         my $module
             = join '::',
             reverse map { ucfirst $_}
@@ -81,7 +80,7 @@ sub xml_error {
     my ($node) = @_;
     my @lines  = split /\r?\n/xms, $node->toString;
     my $indent = '';
-    if ( $lines[0] !~ /^\s+/xms && $lines[-1] =~ /^(\s+)/xms ) {
+    if ( $lines[-1] =~ /^(\s+)/xms ) {
         $indent = $1;
     }
     my $error = $indent . $node->toString."\n at ";
@@ -101,7 +100,7 @@ W3C::SOAP::Utils - Utility functions to be used with C<W3C::SOAP> modules
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Utils version 0.11.
+This documentation refers to W3C::SOAP::Utils version 0.12.
 
 =head1 SYNOPSIS
 
