@@ -8,7 +8,6 @@ package W3C::SOAP::WSDL::Document::Port;
 
 use Moose;
 use warnings;
-use version;
 use Carp;
 use Scalar::Util;
 use List::Util;
@@ -19,7 +18,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 
 extends 'W3C::SOAP::Document::Node';
 
-our $VERSION     = version->new('0.11');
+our $VERSION = 0.12;
 
 has binding => (
     is         => 'rw',
@@ -48,7 +47,11 @@ sub _binding {
 
 sub _address {
     my ($self) = @_;
-    my ($address) = $self->document->xpc->findnodes('soap:address', $self->node);
+    my ($address) = $self->document->xpc->findnodes('soap:address | soap12:address', $self->node);
+    if (!$address) {
+        confess "Can't find address in:\n" . $self->node->toString . "\n";
+    }
+
     return $address->getAttribute('location');
 }
 
@@ -62,7 +65,7 @@ W3C::SOAP::WSDL::Document::Port - Represents the ports in a WSDL document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Document::Port version 0.11.
+This documentation refers to W3C::SOAP::WSDL::Document::Port version 0.12.
 
 
 =head1 SYNOPSIS
