@@ -8,7 +8,6 @@ package W3C::SOAP::XSD::Document;
 
 use Moose;
 use warnings;
-use version;
 use Carp qw/carp croak cluck confess longmess/;
 use Scalar::Util;
 use List::Util;
@@ -28,7 +27,7 @@ use W3C::SOAP::Utils qw/normalise_ns ns2module/;
 
 extends 'W3C::SOAP::Document';
 
-our $VERSION = version->new('0.11');
+our $VERSION = 0.12;
 
 has element_form_default => (
     is         => 'rw',
@@ -140,7 +139,7 @@ sub _imports {
     for my $import (@nodes) {
         next if $import->getAttribute('namespace') && $import->getAttribute('namespace') eq 'http://www.w3.org/2001/XMLSchema';
 
-        my $location = $import->getAttribute('schemaLocation');
+        my $location = $import->getAttribute('schemaLocation') || $import->getAttribute('namespace');
         if ($location) {
 
             if ( $self->location && (
@@ -181,7 +180,7 @@ sub _includes {
     for my $include (@nodes) {
         next if $include->getAttribute('namespace') && $include->getAttribute('namespace') eq 'http://www.w3.org/2001/XMLSchema';
 
-        my $location = $include->getAttribute('schemaLocation');
+        my $location = $include->getAttribute('schemaLocation') || $include->getAttribute('namespace');
         if ($location) {
 
             if ( $self->location && $self->location =~ m{^(?:https?|ftp)://}xms ) {
@@ -418,7 +417,7 @@ W3C::SOAP::XSD::Document - Represents a XMLSchema Document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document version 0.11.
+This documentation refers to W3C::SOAP::XSD::Document version 0.12.
 
 =head1 SYNOPSIS
 
